from django.http import HttpResponseForbidden

from .models import SpamIP


class BlockSpamIPMiddleware(object):
    """Middleware to block access to ip addresses in spam list."""

    def process_request(self, request):
        remote_ip = request.META['REMOTE_ADDR']
        if SpamIP.objects.filter(ip_address=remote_ip).exists():
            return HttpResponseForbidden()



from django.db import models


class SpamIP(models.Model):
    ip_address = models.GenericIPAddressField(unique=True, db_index=True)
    created_on = models.DateTimeField(auto_now_add=True)
    updated_on = models.DateTimeField(auto_now=True)

    def __str__(self):
        return self.ip_address



from .models import SpamIP


def antispam_processor(request):
    """Context processor to make SITE_CONFIG available to all templates."""

    return {'is_spam_ip': SpamIP.objects.filter(ip_address=request.META['REMOTE_ADDR']).exists()}


from django.http import HttpResponseForbidden

from .models import SpamIP


def block_spam_ip(function):
    """Decorator to block access by ip addresses in spam ip list."""
    def wrap(request, *args, **kwargs):
        remote_ip = request.META['REMOTE_ADDR']
        if SpamIP.objects.filter(ip_address=remote_ip).exists():
            return HttpResponseForbidden()
        else:
            return function(request, *args, **kwargs)

    wrap.__doc__ = function.__doc__
    wrap.__name__ = function.__name__
    return wrap



# -*- coding: utf-8 -*-
# Generated by Django 1.9.2 on 2016-03-19 10:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SpamIP',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ip_address', models.GenericIPAddressField(db_index=True, unique=True)),
                ('created_on', models.DateTimeField(auto_now_add=True)),
                ('updated_on', models.DateTimeField(auto_now=True)),
            ],
        ),
    ]



from django.contrib import admin

from .models import SpamIP


@admin.register(SpamIP)
class SpamIPAdmin(admin.ModelAdmin):
    list_display = ['ip_address', 'created_on']
    search_fields = ['ip_address']



import os
from setuptools import setup


os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='crimson_antispam',
    packages=['antispam'],
    version='0.1.1',
    include_package_data=True,
    license='BSD License',
    description='Anti-spam package for django framework',
    author='Tony J',
    author_email='tony@crimsonhack.com',
    url='https://github.com/tony-joseph/crimson_antispam',
    download_url='https://github.com/tony-joseph/crimson_antispam/archive/v0.1.0.tar.gz',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
    ],
)



from django.db import IntegrityError

from .models import SpamIP


def add_spam_ip(ip_address):
    """ Function to add a new ip address to spam list.
    :param spam_ip: either IPv4 or IPv6 address.
    :return: None
    """

    try:
        SpamIP.objects.create(ip_address=ip_address)
    except IntegrityError:
        # If ip address is already in database, ignore
        pass


def bulk_add_spam_ip(ip_address_list):
    """ Function to add a list or tuple of ip addresses into spam list.
    :param ip_address_list: list or tuple of IPv4 or IPv6 addresses.
    :return: None
    """

    for ip_address in ip_address_list:
        add_spam_ip(ip_address)


def is_spam_ip(ip_address):
    """ Checks whether the ip address is in spam list.
    :param ip_address: IPv4 or IPv6 ip address
    :return: True if the ip address is in spam list, else False
    """

    return SpamIP.objects.filter(ip_address=ip_address).exists()


def remove_spam_ip(ip_address):
    """ Removes the ip address from spam list if it is in spam list.
    :param ip_address: IPv4 or IPv6 ip address
    :return: None
    """

    SpamIP.objects.filter(ip_address=ip_address).delete()
